@@ -1,15 +1,14 @@
 /* { dg-do compile } */
-/* { dg-options "-O -fno-tree-sra --param max-aliased-vops=0 --param max-fields-for-field-sensitive=0 -fdump-tree-fre-details" } */
+/* { dg-options "-O -fno-tree-sra -fdump-tree-fre-details" } */
 
-/* Should be optimized, propagating &a into (*p)[i] with parameters
-     --param max-aliased-vops=0 --param max-fields-for-field-sensitive=0
-   which means max 1 VOP per stmt and no SFTs.  */
+/* Should be optimized, propagating &a into (*p)[i].  */
 
 struct Foo
 {
   void *data;
   double size;
 };
+void bar(double *);
 void foo(double (*q)[4])
 {
   struct Foo tmp1;
@@ -25,6 +24,7 @@ void foo(double (*q)[4])
  	 this store to tmp1 here.  */
       tmp1.size -= 1.0;
     }
+  bar(a);
 }
 
 /* { dg-final { scan-tree-dump "Inserted .* &a" "fre" } } */
