@@ -5,8 +5,12 @@
 #ifndef __ASSEMBLER__
 extern int func(void);
 #else
+#ifdef __sun__
+.globl func
+#else
 .global func
-.type func,%function
+#endif
+.type func,@function
 .align 4
 func:
         ret
