@@ -1,6 +1,6 @@
+#import "../../objc-obj-c++-shared/Object1.h"
 #include <objc/objc.h>
 #include <objc/objc-api.h>
-#include <objc/Object.h>
 
 struct A {
   int i;
@@ -22,4 +22,3 @@ struct A {
 @end
 
 #include "bf-common.h"
-
